@@ -14,9 +14,10 @@ Usage::
     ```
 """
 import sys
+from collections.abc import Mapping, Sequence
 from datetime import datetime
 from decimal import Decimal
-from typing import Any, Dict, Mapping, Sequence, Set, Type, Union, overload
+from typing import Any, Dict, Set, Type, Union, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -288,7 +289,8 @@ class DynamoDBClient(BaseClient):
         StreamSpecification: StreamSpecificationTypeDef = ...,
         SSESpecification: SSESpecificationTypeDef = ...,
         Tags: Sequence[TagTypeDef] = ...,
-        TableClass: TableClassType = ...
+        TableClass: TableClassType = ...,
+        DeletionProtectionEnabled: bool = ...
     ) -> CreateTableOutputTypeDef:
         """
         The `CreateTable` operation adds a new table to your account.
@@ -399,7 +401,7 @@ class DynamoDBClient(BaseClient):
         self, *, TableName: str, IndexName: str = ...
     ) -> DescribeContributorInsightsOutputTypeDef:
         """
-        Returns information about contributor insights, for a given table or global
+        Returns information about contributor insights for a given table or global
         secondary index.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.describe_contributor_insights)
@@ -1168,7 +1170,8 @@ class DynamoDBClient(BaseClient):
         StreamSpecification: StreamSpecificationTypeDef = ...,
         SSESpecification: SSESpecificationTypeDef = ...,
         ReplicaUpdates: Sequence[ReplicationGroupUpdateTypeDef] = ...,
-        TableClass: TableClassType = ...
+        TableClass: TableClassType = ...,
+        DeletionProtectionEnabled: bool = ...
     ) -> UpdateTableOutputTypeDef:
         """
         Modifies the provisioned throughput settings, global secondary indexes, or
