@@ -27,9 +27,10 @@ Usage::
     scan_paginator: ScanPaginator = client.get_paginator("scan")
     ```
 """
+from collections.abc import Mapping, Sequence
 from datetime import datetime
 from decimal import Decimal
-from typing import Any, Generic, Iterator, Mapping, Sequence, Set, TypeVar, Union
+from typing import Any, Generic, Iterator, Set, TypeVar, Union
 
 from botocore.paginate import PageIterator, Paginator
 
