@@ -167,6 +167,7 @@ class Table(ServiceResource):
     sse_description: SSEDescriptionResponseMetadataTypeDef
     archival_summary: ArchivalSummaryResponseMetadataTypeDef
     table_class_summary: TableClassSummaryResponseMetadataTypeDef
+    deletion_protection_enabled: bool
     name: str
 
     def batch_writer(self, overwrite_by_pkeys: List[str] = ...) -> BatchWriter:
@@ -496,7 +497,8 @@ class Table(ServiceResource):
         StreamSpecification: StreamSpecificationTableTypeDef = ...,
         SSESpecification: SSESpecificationTableTypeDef = ...,
         ReplicaUpdates: Sequence[ReplicationGroupUpdateTableTypeDef] = ...,
-        TableClass: TableClassType = ...
+        TableClass: TableClassType = ...,
+        DeletionProtectionEnabled: bool = ...
     ) -> "_Table":
         """
         Modifies the provisioned throughput settings, global secondary indexes, or
@@ -648,7 +650,8 @@ class DynamoDBServiceResource(ServiceResource):
         StreamSpecification: StreamSpecificationServiceResourceTypeDef = ...,
         SSESpecification: SSESpecificationServiceResourceTypeDef = ...,
         Tags: Sequence[TagServiceResourceTypeDef] = ...,
-        TableClass: TableClassType = ...
+        TableClass: TableClassType = ...,
+        DeletionProtectionEnabled: bool = ...
     ) -> _Table:
         """
         The `CreateTable` operation adds a new table to your account.
